==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/azurestackhci/kotlin/outputs/GalleryImageStatusResponse.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.azurestackhci.kotlin.outputs

import kotlin.Double
import kotlin.String
import kotlin.Suppress

/**
 * The observed state of gallery images
 * @property downloadStatus The download status of the gallery image
 * @property errorCode GalleryImage provisioning error code
 * @property errorMessage Descriptive error message
 * @property progressPercentage The progress of the operation in percentage
 * @property provisioningStatus
 */
public data class GalleryImageStatusResponse(
    public val downloadStatus: GalleryImageStatusResponseDownloadStatus? = null,
    public val errorCode: String? = null,
    public val errorMessage: String? = null,
    public val progressPercentage: Double? = null,
    public val provisioningStatus: GalleryImageStatusResponseProvisioningStatus? = null,
) {
    public companion object {
        public
        fun toKotlin(javaType: com.pulumi.azurenative.azurestackhci.outputs.GalleryImageStatusResponse):
            GalleryImageStatusResponse = GalleryImageStatusResponse(
            downloadStatus = javaType.downloadStatus().map({ args0 ->
                args0.let({ args0 ->
                    com.pulumi.azurenative.azurestackhci.kotlin.outputs.GalleryImageStatusResponseDownloadStatus.Companion.toKotlin(args0)
                })
            }).orElse(null),
            errorCode = javaType.errorCode().map({ args0 -> args0 }).orElse(null),
            errorMessage = javaType.errorMessage().map({ args0 -> args0 }).orElse(null),
            progressPercentage = javaType.progressPercentage().map({ args0 -> args0 }).orElse(null),
            provisioningStatus = javaType.provisioningStatus().map({ args0 ->
                args0.let({ args0 ->
                    com.pulumi.azurenative.azurestackhci.kotlin.outputs.GalleryImageStatusResponseProvisioningStatus.Companion.toKotlin(args0)
                })
            }).orElse(null),
        )
    }
}

==> pulumi-azure-native-kotlin-2.44.1.0-sources.jar: com/pulumi/azurenative/azurestackhci/kotlin/outputs/GalleryImageStatusResponse.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.azurestackhci.kotlin.outputs

import kotlin.Double
import kotlin.String
import kotlin.Suppress

/**
 * The observed state of gallery images
 * @property downloadStatus The download status of the gallery image
 * @property errorCode GalleryImage provisioning error code
 * @property errorMessage Descriptive error message
 * @property progressPercentage The progress of the operation in percentage
 * @property provisioningStatus
 */
public data class GalleryImageStatusResponse(
    public val downloadStatus: GalleryImageStatusResponseDownloadStatus? = null,
    public val errorCode: String? = null,
    public val errorMessage: String? = null,
    public val progressPercentage: Double? = null,
    public val provisioningStatus: GalleryImageStatusResponseProvisioningStatus? = null,
) {
    public companion object {
        public fun toKotlin(javaType: com.pulumi.azurenative.azurestackhci.outputs.GalleryImageStatusResponse): GalleryImageStatusResponse = GalleryImageStatusResponse(
            downloadStatus = javaType.downloadStatus().map({ args0 ->
                args0.let({ args0 ->
                    com.pulumi.azurenative.azurestackhci.kotlin.outputs.GalleryImageStatusResponseDownloadStatus.Companion.toKotlin(args0)
                })
            }).orElse(null),
            errorCode = javaType.errorCode().map({ args0 -> args0 }).orElse(null),
            errorMessage = javaType.errorMessage().map({ args0 -> args0 }).orElse(null),
            progressPercentage = javaType.progressPercentage().map({ args0 -> args0 }).orElse(null),
            provisioningStatus = javaType.provisioningStatus().map({ args0 ->
                args0.let({ args0 ->
                    com.pulumi.azurenative.azurestackhci.kotlin.outputs.GalleryImageStatusResponseProvisioningStatus.Companion.toKotlin(args0)
                })
            }).orElse(null),
        )
    }
}
